@@ -6,6 +6,7 @@ from typing import Any
 import pandas as pd
 import smart_open
 
+from wpdatautil.pathlib import path_to_uri
 from wpdatautil.timeit import Timer
 
 log = logging.getLogger(__name__)
@@ -19,7 +20,7 @@ def read_parquet_path(path: Path, *, df_description: str = "dataframe", **kwargs
     :param kwargs: These are forwarded to `pd.read_parquet`.
     """
     path.parent.mkdir(parents=True, exist_ok=True)
-    return read_parquet_uri(path.as_uri(), df_description=df_description, **kwargs)
+    return read_parquet_uri(path_to_uri(path), df_description=df_description, **kwargs)
 
 
 def write_parquet_path(df: pd.DataFrame, path: Path, *, df_description: str = "dataframe", **kwargs: Any) -> None:
@@ -30,7 +31,7 @@ def write_parquet_path(df: pd.DataFrame, path: Path, *, df_description: str = "d
     :param df_description: Optional description of dataframe.
     :param kwargs: These are forwarded to `df.to_parquet`.
     """
-    write_parquet_uri(df, uri=path.as_uri(), df_description=df_description, **kwargs)
+    write_parquet_uri(df, uri=path_to_uri(path), df_description=df_description, **kwargs)
 
 
 def read_parquet_uri(uri: str, *, df_description: str = "dataframe", **kwargs: Any) -> pd.DataFrame:
